pub struct BasicAuth { /* private fields */ }Expand description
basic auth handler
Implementations
Sourceimpl BasicAuth
impl BasicAuth
Sourcepub fn new(username: impl Into<String>, password: impl Into<String>) -> Self
pub fn new(username: impl Into<String>, password: impl Into<String>) -> Self
build a new basic auth handler that accepts exactly this username and password
Only a digest of the credentials is retained, and it is compared in constant time.
Sourcepub fn validate_fn<F>(predicate: F) -> Self
pub fn validate_fn<F>(predicate: F) -> Self
build a new basic auth handler that accepts any credentials for which the provided predicate returns true
let basic_auth = BasicAuth::validate_fn(|credentials| {
credentials.username().starts_with("admin-")
&& credentials.password() == std::env::var("ADMIN_PASSWORD").unwrap()
});A predicate that compares secrets should do so in constant time, as BasicAuth::new
does.
Sourcepub fn validate_async_fn<F, Fut>(predicate: F) -> Self
pub fn validate_async_fn<F, Fut>(predicate: F) -> Self
build a new basic auth handler that accepts any credentials for which the provided async predicate returns true, such as a database lookup and a password hash comparison
let basic_auth = BasicAuth::validate_async_fn(|credentials| async move {
match look_up(credentials.username()).await {
Some(hash) => verify(credentials.password(), &hash),
None => false,
}
});Sourcepub fn with_realm(self, realm: &str) -> Self
pub fn with_realm(self, realm: &str) -> Self
provide a realm for the www-authenticate response sent by this handler
Sourcepub fn realm(&self) -> Option<&str>
pub fn realm(&self) -> Option<&str>
the realm provided to BasicAuth::with_realm, if any